package com.sky.common.interceptor;

import com.sky.common.constant.MessageConstant;
import com.sky.common.context.BaseContext;
import com.sky.common.properties.RedisTokenProperties;
import com.sky.common.utils.InterceptorUtil;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@Component
@Slf4j
public class RedisTokenAdminInterceptor implements HandlerInterceptor {
    @Autowired
    private RedisTokenProperties redisTokenProperties;
    @Autowired
    private RedisTemplate<String, Object> redisTemplate;

    public boolean preHandle(@NotNull HttpServletRequest request, @NotNull HttpServletResponse response, @NotNull Object handler) throws IOException {
        // 判断当前兰街道的是Controller的方法还是其它资源 拦截到的不是动态方法，直接放行
        if (!(handler instanceof HandlerMethod)) return true;

        // 1. 从请求头中获取令牌
        String token = request.getHeader(redisTokenProperties.getAdminTokenName());
        log.info("jwt校验：{}", token);
        if (token == null) {
            InterceptorUtil.unLoginInterceptor(response);
            return false;
        }

        try {
            Object empId = redisTemplate.opsForValue().get(token);
            log.info("当前员工ID：{}", empId);
            if (empId == null) {
                InterceptorUtil.customLoginInterceptor(response, MessageConstant.USER_TOKEN_OUT_OF_DATE, "");
                return false;
            }
            // 3. 通过放行
            BaseContext.setUserId(Long.valueOf(empId.toString()));
            return true;
        } catch (Exception exception) {
            InterceptorUtil.customLoginInterceptor(response, exception.getMessage(), "");
            return false;
        }
    }
}
