package com.sky.mapper;

import com.github.pagehelper.Page;
import com.sky.annotation.AutoFill;
import com.sky.common.enumeration.OperationType;
import com.sky.pojo.dto.DishPageQueryDTO;
import com.sky.pojo.entity.Dish;
import com.sky.pojo.vo.DishVO;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;
import java.util.Map;

@Mapper
public interface DishMapper {

    /**
     * 根据分类id查询菜品数量
     *
     * @param categoryId 分类id
     * @return 数量
     */
    Integer countByCategoryId(Long categoryId);

    /**
     * 向菜品表插入1条数据
     *
     * @param dish 前端新增菜品
     */
    @AutoFill(value = OperationType.INSERT)
    void insert(Dish dish);

    /**
     * 菜品分页查询
     *
     * @param dto 菜品分页查询-前端参数
     * @return 封装分页查询结果
     */
    Page<DishVO> pageQuery(DishPageQueryDTO dto);


    /**
     * 判断当前菜品是否是起售中菜品
     *
     * @param id id
     */
    Dish getById(Long id);

    /**
     * 删除菜品表中菜品数据
     *
     * @param ids 被删除的id
     */
    void deleteByIds(List<Long> ids);

    /**
     * 修改菜品信息
     *
     * @param dish 菜品信息
     */
    @AutoFill(value = OperationType.UPDATE)
    void update(Dish dish);

    /**
     * 起售套餐时，判断套餐内是否有停售菜品
     *
     * @param id id
     * @return List<Dish>
     */
    List<Dish> getBySetmealId(Long id);

    /**
     * 查询菜品
     *
     * @param dish 菜品
     * @return List<Dish>
     */
    List<Dish> list(Dish dish);

    /**
     * 根据条件统计菜品数量
     *
     * @param map map
     * @return 数量
     */
    Integer countByMap(Map map);
}
