package com.sky.service;


import com.sky.common.result.PageResult;
import com.sky.pojo.dto.DishDTO;
import com.sky.pojo.dto.DishPageQueryDTO;
import com.sky.pojo.entity.Dish;
import com.sky.pojo.vo.DishVO;

import java.util.List;

public interface DishService {
    /**
     * 新增菜品
     *
     * @param dishPageQueryDTO 前端新增菜品
     */
    void saveWithFlavor(DishDTO dishPageQueryDTO);

    /**
     * 菜品分页查询
     *
     * @param dishPageQueryDTO 菜品分页查询-前端参数
     * @return 封装分页查询结果
     */
    PageResult<DishVO> pageQuery(DishPageQueryDTO dishPageQueryDTO);

    /**
     * 菜品批量删除
     *
     * @param ids 删除的is
     */
    void deleteBatch(List<Long> ids);

    /**
     * 根据id查询菜品和对应的口味数据
     *
     * @param id 菜品id
     * @return DishVO
     */
    DishVO getById(Long id);

    /**
     * 修改菜品
     *
     * @param dto 前端请求菜品
     */
    void updateWithFlavor(DishDTO dto);

    /**
     * 菜品起售、停售
     *
     * @param status 起售、停售
     */
    void updateWithStatus(Integer status, Long id);

    /**
     * 根据分类id查询菜品
     *
     * @param categoryId 分类id
     * @return List<DishVO>
     */
    List<Dish> getByCategoryId(Long categoryId);

    /**
     * 条件查询菜品和口味
     *
     * @param dish 菜品
     * @return List<DishVO>
     */
    List<DishVO> listWithFlavor(Dish dish);
}
